@@ -30,7 +30,11 @@ class GitService:
         self.git = local.cmd.git
 
     def perform_action(
-        self, action: GitAction, revision: str, directory: Optional[Path] = None
+        self,
+        action: GitAction,
+        revision: str,
+        directory: Optional[Path] = None,
+        branch_name: Optional[str] = None,
     ) -> None:
         """
         Perform the given git operation.
@@ -38,27 +42,35 @@ class GitService:
         :param action: Git operation to perform.
         :param revision: Git revision to perform operation with.
         :param directory: Directory of git repository.
+        :param branch_name: Name of branch for git checkout.
         """
         if action == GitAction.NONE:
             return
 
         self.fetch(directory)
         if action == GitAction.CHECKOUT:
-            self.checkout(revision, directory)
+            self.checkout(revision, directory, branch_name)
         elif action == GitAction.REBASE:
             self.rebase(revision, directory)
         elif action == GitAction.MERGE:
             self.merge(revision, directory)
 
-    def checkout(self, revision: str, directory: Optional[Path] = None) -> None:
+    def checkout(
+        self, revision: str, directory: Optional[Path] = None, branch_name: Optional[str] = None
+    ) -> None:
         """
         Checkout the given revision.
 
         :param revision: Revision to checkout.
         :param directory: Directory to execute command at.
+        :param branch_name: Name of branch for git checkout.
         """
+        args = ["checkout"]
+        if branch_name is not None:
+            args += ["-b", branch_name]
+        args.append(revision)
         with local.cwd(self._determine_directory(directory)):
-            self.git["checkout", revision]()
+            self.git[args]()
 
     def fetch(self, directory: Optional[Path] = None) -> None:
         """
